package bdchain.api;

import bdchain.api.grpc.GetLedgersResponse;
import bdchain.api.grpc.TransactionType;

import java.util.concurrent.ExecutionException;

public class Test {

  static final String ledger = "test";
  static final int block_number = 1;
  static final String block_hash = "0x0";
  static final int index = 0;

  private static void testFutureApi() throws InterruptedException {

    TransactionLedgerClient tlClient = new TransactionLedgerClient("localhost", 8004);
    try {
      System.out.println(tlClient.createLedger(ledger).get().getOk());
      GetLedgersResponse r = tlClient.getLedgers().get();
      for (int i = 0; i < r.getLedgersCount(); i++) {
        System.out.println(r.getLedgers(i));
      }
      System.out.println(
          tlClient
              .sendTransaction(ledger, TransactionType.RECORD, "0x0", "0x1", "data".getBytes())
              .get()
              .getHash());
    } catch (ExecutionException e) {
      e.printStackTrace();
    }
    tlClient.shutdown();

    AccountingChainClient acClient = new AccountingChainClient("localhost", 8013);
    try {
      System.out.println(acClient.blockNumber(ledger).get().getBlockNumber());
      System.out.println(acClient.getBlockByNumber(ledger, block_number, false).get().toString());
      System.out.println(acClient.getBlockByNumber(ledger, block_number, true).get().toString());
      System.out.println(acClient.getBlockByHash(ledger, block_hash, false).get().toString());
      System.out.println(acClient.getBlockByHash(ledger, block_hash, true).get().toString());
      System.out.println(acClient.getTransactionByHash(ledger, "0x0").get().toString());
      System.out.println(
          acClient
              .getTransactionByBlockNumberAndIndex(ledger, block_number, index)
              .get()
              .toString());
      System.out.println(
          acClient.getTransactionByBlockHashAndIndex(ledger, block_hash, index).get().toString());
    } catch (ExecutionException e) {
      e.printStackTrace();
    }
    acClient.shutdown();
  }

  private static void testSyncApi() throws InterruptedException {

    TransactionLedgerClient tlClient = new TransactionLedgerClient("localhost", 8004);
    System.out.println(tlClient.createLedgerSync(ledger).getOk());
    GetLedgersResponse r = tlClient.getLedgersSync();
    for (int i = 0; i < r.getLedgersCount(); i++) {
      System.out.println(r.getLedgers(i));
    }
    System.out.println(
        tlClient
            .sendTransactionSync(ledger, TransactionType.RECORD, "0x0", "0x1", "data".getBytes())
            .getHash());
    tlClient.shutdown();

    AccountingChainClient acClient = new AccountingChainClient("localhost", 8013);
    System.out.println(acClient.blockNumberSync(ledger).getBlockNumber());
    System.out.println(acClient.getBlockByNumberSync(ledger, block_number, false).toString());
    System.out.println(acClient.getBlockByNumberSync(ledger, block_number, true).toString());
    System.out.println(acClient.getBlockByHashSync(ledger, block_hash, false).toString());
    System.out.println(acClient.getBlockByHashSync(ledger, block_hash, true).toString());
    System.out.println(acClient.getTransactionByHashSync(ledger, "0x0").toString());
    System.out.println(
        acClient.getTransactionByBlockNumberAndIndexSync(ledger, block_number, index).toString());
    System.out.println(
        acClient.getTransactionByBlockHashAndIndexSync(ledger, block_hash, index).toString());
    acClient.shutdown();
  }

  public static void main(String[] args) throws InterruptedException {
    testFutureApi();
    testSyncApi();
  }
}
